# Plot Vout drift/stability of the voltage logged by using Hioki's RmLogger and DM7276
# Rev.1.1 (Sep. 28, 2022) Written by Takayuki HOSODA <lyuka@finetune.co.jp>
#
# Arguments |  Examples  | Unit
#   TARGET  | 2W3E       |
#   NAME    | F0101VR    |
#   DATE    | 2022-09-15 | year-month-day
#   TIME    | 02:10:44   | hour:minute:second
#   XDIV    | 1          | hour
#   YDIV    | 10e-6      | Volt
#   YNOM    | 2.5        | Volt
#   TDIV    | 1          | deg.C
#   TNOM    | 25         | deg.C
#
# Data format: Examples
#   #       date            time            Vout            Ta
#   2       2022-09-15      02:10:44        +02.500002E+00  +25.06
#
reset
set encoding iso_8859_1
set grid 
set style data lines
set key left Left
set key spacing 1.5
readdt(date, time)=(strptime('%Y-%m-%d', strcol(date)) + strptime('%H:%M:%S', strcol(time)))

### Drift characteristics ###
#
set xrange [ * : * ]
set xtics  XDIV
set xlabel "Elapsed time [hr]" 
Vcenter = YNOM
Vdiv    = YDIV
set yrange [ Vcenter - 10 * Vdiv : Vcenter + 10 * Vdiv ]
set ytics  Vdiv
set format y "%6.5f"
set ylabel "{/Helvetica-Oblique V}_{out} [V] (".sprintf("%g", Vdiv * 1e6)."{/Symbol m}V / div, 100 PLC)" 
set y2range [ 20.000 : 30.000 ]
set y2tics  1
set format y2 "%2.1f"

### DUT dependent
#
DUT = NAME." #".TARGET
set terminal dumb
stats TARGET.".dat" u ($5):($4)
#hr_0 = strptime('%Y-%m-%d', "2022-09-15") + strptime('%H:%M:%S', "02:10:44")
hr_0 = strptime('%Y-%m-%d', DATE) + strptime('%H:%M:%S', TIME)
set title "{/Helvetica-Oblique V}_{out} drift at room temperature (DUT : ".DUT.")" 
set y2label "{/Helvetica-Oblique T}_{a} [\260C]" 
set terminal postscript solid color enhanced
set output TARGET.".ps"

plot \
TARGET.".dat" u ((readdt(2, 3) - hr_0) / 3600):($5) axis x1y2 t "{/Helvetica-Oblique T}_{a}" lt 3,\
TARGET.".dat" u ((readdt(2, 3) - hr_0) / 3600):($4) t "{/Helvetica-Oblique V}_{out}" lt 1,\
STATS_mean_y t "{/Helvetica-Oblique V}_{/Symbol m} = ".sprintf("%7.7f", STATS_mean_y) lt 2,\
STATS_mean_y + 3 * STATS_stddev_y  t "{/Helvetica-Oblique V}_{{/Symbol m \261} 3 {/Symbol s}} | {/Symbol s} = ".sprintf("%3.3g", STATS_stddev_y) lt 4,\
STATS_mean_y - 3 * STATS_stddev_y  t "" lt 4
#set output
hr_elaps = GPVAL_DATA_X_MAX

### Stability in scatter graph ###
#
set xrange [ TNOM - 10 * TDIV : TNOM + 10 * TDIV ]
set yrange [ Vcenter - 10 * Vdiv : Vcenter + 10 * Vdiv ]
set xlabel "{/Helvetica-Oblique T}_{a} [\260C]"
set ylabel "{/Helvetica-Oblique V}_{out} [V] (10 {/Symbol m}V/div, 100 PLC)"
set xtics TDIV
set ytics Vdiv
set format y "%7.5f"
set y2label ""
unset y2tics
set title "{/Helvetica-Oblique V}_{out} stability at room temperature (for ".sprintf("%4.1f", hr_elaps)." hours, DUT : ".DUT.")"
set label 1 "{/Helvetica-Oblique V}_{/Symbol m} = ".sprintf("%7.7f", STATS_mean_y)   at graph 0.05, graph 0.125 tc lt 3
set label 2 "{/Helvetica-Oblique V}_{/Symbol s} = ".sprintf("%3.3g", STATS_stddev_y) at graph 0.05, graph 0.075
set label 3 "{/Helvetica-Oblique T}_{/Symbol m} = ".sprintf("%5.2f", STATS_mean_x)   at graph 0.45, graph 0.125 tc lt 3
set label 4 "{/Helvetica-Oblique T}_{/Symbol s} = ".sprintf("%3.3g", STATS_stddev_x) at graph 0.45, graph 0.075
set style data dot
#set terminal postscript solid color enhanced
#set output "stability".TARGET.".ps"
plot TARGET.".dat" u ($5):($4) t "{/Helvetica-Oblique V}_{out}"
set output
#set terminal wxt
#rep
#    EOF
